% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hiReadsProcessor.R
\name{read.sampleInfo}
\alias{read.sampleInfo}
\title{Read a sample information file and format appropriate metadata.}
\usage{
read.sampleInfo(sampleInfoPath = NULL, splitBySector = TRUE)
}
\arguments{
\item{sampleInfoPath}{full or relative path to the sample information file, 
which holds samples to quadrant/lane associations along with other metadata 
required to trim sequences or process it.}

\item{splitBySector}{split the data frame into a list by sector column. 
Default is TRUE.}
}
\value{
if splitBySector=TRUE, then an object of SimpleList named by 
quadrant/lane information defined in sampleInfo file, else a dataframe.
}
\description{
Given a sample information file, the function checks if it includes required 
information to process samples present on each sector/quadrant/region/lane. 
The function also adds other columns required for processing with default 
values if not already defined ahead of time.
}
\details{
\itemize{
 \item Required Column Description:
   \itemize{
 	\item sector => region/quadrant/lane of the sequencing plate the sample 
   comes from. If files have been split by samples apriori, then the filename
   associated per sample without the extension. If this is a filename, then 
   be sure to enable 'alreadyDecoded' parameter in \code{\link{findBarcodes}}, 
   since contents of this column is pasted together with 'seqfilePattern' 
   parameter in \code{\link{read.SeqFolder}} to find the appropriate file 
   needed. For paired end data, this is basename of the FASTA/Q file holding 
   the sample data from the LTR side. For example, files such as 
   Lib3_L001_R2_001.fastq.gz or Lib3_L001_R2_001.fastq would be 
   Lib3_L001_R2_001, and consequently Lib3_L001_R1_001 would be used as the 
   second pair!
 	\item barcode => unique 4-12bp DNA sequence which identifies the sample. 
   If providing filename as sector, then leave this blank since it is assumed 
   that the data is already demultiplexed.
 	\item primerltrsequence => DNA sequence of the viral LTR primer 
   with/without the viral LTR sequence following the primer landing site. 
   If already trimmed, then mark this as SKIP.
 	\item sampleName => Name of the sample associated with the barcode
 	\item sampleDescription => Detailed description of the sample
 	\item gender => sex of the sample: male or female or NA
 	\item species => species of the sample: homo sapien, mus musculus, etc.
 	\item freeze => UCSC freeze to which the sample should be aligned to.
 	\item linkerSequence => DNA sequence of the linker adaptor following the 
   genomic sequence. If already trimmed, then mark this as SKIP.
 	\item restrictionEnzyme => Restriction enzyme used for digestion and 
   sample recovery. Can also be one of: Fragmentase or Sonication!
		}
 \item Metadata Parameter Column Description:
  \itemize{
 	\item ltrBitSequence => DNA sequence of the viral LTR following the 
   primer landing site. Default is last 7bps of the primerltrsequence.
 	\item ltrBitIdentity => percent of LTR bit sequence to match during the 
   alignment. Default is 1.
 	\item primerLTRidentity => percent of primer to match during the 
   alignment. Default is .85
 	\item linkerIdentity => percent of linker sequence to match during the 
   alignment. Default is 0.55. Only applies to non-primerID/random tag based 
   linker search.
 	\item primerIdInLinker => whether the linker adaptor used has 
   primerID/random tag in it? Default is FALSE.
 	\item primerIdInLinkerIdentity1 => percent of sequence to match before 
   the random tag. Default is 0.75. Only applies to primerID/random tag 
   based linker search and when primeridinlinker is TRUE.
 	\item primerIdInLinkerIdentity2 => percent of sequence to match after the 
   random tag. Default is 0.50. Only applies to primerID/random tag based 
   linker search and when primeridinlinker is TRUE.
 	\item celltype => celltype information associated with the sample
 	\item user => name of the user who prepared or processed the sample
 	\item pairedEnd => is the data paired end? Default is FALSE.
   \item vectorFile => fasta file containing the vector sequence
		}
 \item Processing Parameter Column Description:
  \itemize{
 	\item startWithin => upper bound limit of where the alignment should 
   start within the query. Default is 3.
 	\item alignRatioThreshold => cuttoff for (alignment span/read length). 
   Default is 0.7.
 	\item genomicPercentIdentity => cuttoff for (1-(misMatches/matches)). 
   Default is 0.98.
 	\item clusterSitesWithin => cluster integration sites within a defined 
   window size based on frequency which corrects for any sequencing errors. 
   Default is 5.
 	\item keepMultiHits => whether to keep sequences/reads that return 
   multiple best hits, aka ambiguous locations. 
 	\item processingDate => the date of processing 
		}
}
}
\examples{
 
runData <- system.file(file.path("extdata", "FLX_sample_run"), 
package = "hiReadsProcessor")
read.sampleInfo(file.path(runData, "sampleInfo.xlsx"))
}
\seealso{
\code{\link{read.SeqFolder}}, \code{\link{findBarcodes}}, 
\code{\link{splitByBarcode}}
}
